---
name: Feature Request
about: Create a request for a new feature
title: ""
labels: enhancement
assignees: ""
---

<!-- What kind of feature would you like to request? -->
- [ ] Additional function parameters, change functionality or change defaults?
- [ ] New estimator in `cr.tl.estimators`?
- [ ] New kernel in `cr.tl.kernels`?
- [ ] New gene trend model in `cr.ul.models`?
- [ ] New plotting function in `cr.pl`?
- [ ] Other?

<!-- Describe the feature requested below: -->
...
